@@ -89,18 +89,20 @@ static const guint8 direction_offsets[] = {
 static const char wrap_mode[] =
   "none\0"
   "char\0"
-  "word";
+  "word\0"
+  "word_char";
 static const guint8 wrap_mode_offsets[] = {
-  0, 5, 10
+  0, 5, 10, 15
 };
 
 static const char underline[] =
   "none\0"
   "single\0"
   "double\0"
-  "low";
+  "low\0"
+  "error";
 static const guint8 underline_offsets[] = {
-  0, 5, 12, 19
+  0, 5, 12, 19, 23
 };
 
 static void atk_text_base_init (AtkTextIface *class);
@@ -298,7 +300,7 @@ atk_text_get_character_at_offset (AtkText      *text,
  * string is from the line start after the offset to the next line start.
  *
  * If the boundary_type is ATK_TEXT_BOUNDARY_LINE_END the returned string
- * is from the line end at or after the offset to the next line start.
+ * is from the line end at or after the offset to the next line end.
  *
  * Returns: the text after @offset bounded by the specified @boundary_type.
  **/
@@ -597,9 +599,10 @@ atk_text_get_character_extents (AtkText *text,
 }
 
 /**
- *atk_text_get_run_attributes:
+ * atk_text_get_run_attributes:
  *@text: an #AtkText
- *@offset: the offset at which to get the attributes
+ *@offset: the offset at which to get the attributes, -1 means the offset of
+ *the character to be inserted at the caret location.
  *@start_offset: the address to put the start offset of the range
  *@end_offset: the address to put the end offset of the range
  *
@@ -611,9 +614,9 @@ atk_text_get_character_extents (AtkText *text,
  *attributes that can be returned. Note that other attributes may also be 
  *returned.
  *
- *Returns: an #AtkAttributeSet which contains the attributes explicitly set
- *at @offset. This #AtkAttributeSet should be freed by a call to
- *atk_attribute_set_free().
+ *Returns: (transfer full): an #AtkAttributeSet which contains the attributes
+ * explicitly set at @offset. This #AtkAttributeSet should be freed by a call
+ * to atk_attribute_set_free().
  **/
 AtkAttributeSet* 
 atk_text_get_run_attributes (AtkText          *text,
@@ -636,7 +639,7 @@ atk_text_get_run_attributes (AtkText          *text,
   else
     real_end_offset = &local_end_offset;
 
-  if (offset < 0)
+  if (offset < -1)
     return NULL;
 
   iface = ATK_TEXT_GET_IFACE (text);
@@ -648,7 +651,7 @@ atk_text_get_run_attributes (AtkText          *text,
 }
 
 /**
- *atk_text_get_default_attributes:
+ * atk_text_get_default_attributes:
  *@text: an #AtkText
  *
  *Creates an #AtkAttributeSet which consists of the default values of
@@ -656,9 +659,9 @@ atk_text_get_run_attributes (AtkText          *text,
  *attributes that can be returned. Note that other attributes may also be 
  *returned.
  *
- *Returns: an #AtkAttributeSet which contains the default values of attributes.
- *at @offset. This #AtkAttributeSet should be freed by a call to
- *atk_attribute_set_free().
+ *Returns: (transfer full): an #AtkAttributeSet which contains the default
+ * values of attributes.  at @offset. this #atkattributeset should be freed by
+ * a call to atk_attribute_set_free().
  */
 AtkAttributeSet* 
 atk_text_get_default_attributes (AtkText          *text)
@@ -937,7 +940,7 @@ atk_text_set_caret_offset (AtkText *text,
  *
  * Get the bounding box for text within the specified range.
  *
- * Since: ATK 1.3
+ * Since: 1.3
  **/
 void
 atk_text_get_range_extents (AtkText          *text,
@@ -970,7 +973,7 @@ atk_text_get_range_extents (AtkText          *text,
  *
  * Get the ranges of text in the specified bounding box.
  *
- * Since: ATK 1.3
+ * Since: 1.3
  *
  * Returns: Array of AtkTextRange. The last element of the array returned 
  *          by this function will be NULL.
@@ -1348,7 +1351,7 @@ atk_text_real_get_bounded_ranges (AtkText          *text,
  * that the array was returned by the function atk_text_get_bounded_ranges
  * and is NULL terminated.
  *
- * Since: ATK 1.3
+ * Since: 1.3
  **/
 void
 atk_text_free_ranges (AtkTextRange **ranges)
